`include "vhd_wishbone_master.svh"
`include "mock_turtle_driver.svh"

module main;

   reg rst_n = 0;
   reg clk_125m = 0, clk_20m = 0;

   always #4ns clk_125m <= ~clk_125m;
   always #25ns clk_20m <= ~clk_20m;
   
   initial begin
      repeat(20) @(posedge clk_125m);
      rst_n = 1;
   end

   // the Device Under Test   
   spec_top
     #(
       .g_simulation(1),
       .g_sim_bypass_gennum(1)
       )
   
   DUT (
	.l_rst_n (rst_n),

        .clk_20m_vcxo_i(clk_20m),

	.clk_125m_pllref_p_i(clk_125m),
	.clk_125m_pllref_n_i(~clk_125m),

        .clk_125m_gtp_p_i(clk_125m),
        .clk_125m_gtp_n_i(~clk_125m),

	.button2_i(button),
	.button1_i(1'b1),

	.sim_slave_i(U_WBMaster.out),
	.sim_slave_o(U_WBMaster.in)
	);

   
    IVHDWishboneMaster U_WBMaster
     (
      .clk_i(DUT.clk_sys),
      .rst_n_i(DUT.rst_n_sys)
      );



   
   initial begin
      automatic CWishboneAccessor acc;
      automatic MockTurtleDriver drv;
      automatic NodeCPUControl csr;

      @(posedge DUT.rst_n_sys);
      @(posedge DUT.clk_sys);

      

      
      acc = U_WBMaster.get_accessor();
      acc.set_mode (PIPELINED);

      drv = new(acc, 'h20000);
      drv.init();

      csr = drv.CPUs();
      csr.load_firmware_bin(0, "../../../software/rt/hw-tests/hello/hello.bin");
      csr.reset_core(0, 0);
     

      forever begin
	 drv.update();
	 #1us;
      end

   end 
  
endmodule // main

